summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/sizehandle.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/sizehandle.cpp')
-rw-r--r--kdevdesigner/designer/sizehandle.cpp70
1 files changed, 35 insertions, 35 deletions
diff --git a/kdevdesigner/designer/sizehandle.cpp b/kdevdesigner/designer/sizehandle.cpp
index eef86747..42b1f665 100644
--- a/kdevdesigner/designer/sizehandle.cpp
+++ b/kdevdesigner/designer/sizehandle.cpp
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
** This file is part of Qt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -35,8 +35,8 @@
#include <tqlabel.h>
#include <klocale.h>
-SizeHandle::SizeHandle( FormWindow *parent, Direction d, WidgetSelection *s )
- : TQWidget( parent )
+SizeHandle::SizeHandle( FormWindow *tqparent, Direction d, WidgetSelection *s )
+ : TQWidget( tqparent )
{
active = TRUE;
setBackgroundMode( active ? PaletteText : PaletteDark );
@@ -44,7 +44,7 @@ SizeHandle::SizeHandle( FormWindow *parent, Direction d, WidgetSelection *s )
widget = 0;
dir =d ;
setMouseTracking( FALSE );
- formWindow = parent;
+ formWindow = tqparent;
sel = s;
updateCursor();
}
@@ -98,7 +98,7 @@ void SizeHandle::setWidget( TQWidget *w )
void SizeHandle::paintEvent( TQPaintEvent * )
{
- if ( ( (FormWindow*)parentWidget() )->currentWidget() != widget )
+ if ( ( (FormWindow*)tqparentWidget() )->currentWidget() != widget )
return;
TQPainter p( this );
p.setPen( blue );
@@ -107,7 +107,7 @@ void SizeHandle::paintEvent( TQPaintEvent * )
void SizeHandle::mousePressEvent( TQMouseEvent *e )
{
- if ( !widget || e->button() != LeftButton || !active )
+ if ( !widget || e->button() != Qt::LeftButton || !active )
return;
oldPressPos = e->pos();
geom = origGeom = TQRect( widget->pos(), widget->size() );
@@ -115,13 +115,13 @@ void SizeHandle::mousePressEvent( TQMouseEvent *e )
void SizeHandle::mouseMoveEvent( TQMouseEvent *e )
{
- if ( !widget || ( e->state() & LeftButton ) != LeftButton || !active )
+ if ( !widget || ( e->state() & Qt::LeftButton ) != Qt::LeftButton || !active )
return;
TQPoint rp = mapFromGlobal( e->globalPos() );
TQPoint d = oldPressPos - rp;
oldPressPos = rp;
- TQPoint checkPos = widget->parentWidget()->mapFromGlobal( e->globalPos() );
- TQRect pr = widget->parentWidget()->rect();
+ TQPoint checkPos = widget->tqparentWidget()->mapFromGlobal( e->globalPos() );
+ TQRect pr = widget->tqparentWidget()->rect();
// ##### move code around a bit to reduce duplicated code here
switch ( dir ) {
@@ -213,7 +213,7 @@ void SizeHandle::mouseMoveEvent( TQMouseEvent *e )
sel->updateGeometry();
oldPressPos += ( p - pos() );
- formWindow->sizePreview()->setText( i18n( "%1/%2" ).arg( widget->width() ).arg( widget->height() ) );
+ formWindow->sizePreview()->setText( i18n( "%1/%2" ).tqarg( widget->width() ).tqarg( widget->height() ) );
formWindow->sizePreview()->adjustSize();
TQRect lg( formWindow->mapFromGlobal( e->globalPos() ) + TQPoint( 16, 16 ),
formWindow->sizePreview()->size() );
@@ -221,55 +221,55 @@ void SizeHandle::mouseMoveEvent( TQMouseEvent *e )
formWindow->sizePreview()->setGeometry( lg );
formWindow->sizePreview()->show();
formWindow->sizePreview()->raise();
- if ( WidgetFactory::layoutType( widget ) != WidgetFactory::NoLayout )
+ if ( WidgetFactory::tqlayoutType( widget ) != WidgetFactory::NoLayout )
formWindow->updateChildSelections( widget );
}
void SizeHandle::mouseReleaseEvent( TQMouseEvent *e )
{
- if ( e->button() != LeftButton || !active )
+ if ( e->button() != Qt::LeftButton || !active )
return;
formWindow->sizePreview()->hide();
- if ( geom != widget->geometry() )
+ if ( geom != widget->tqgeometry() )
formWindow->commandHistory()->addCommand( new ResizeCommand( i18n( "Resize" ),
formWindow,
widget, origGeom,
- widget->geometry() ) );
- formWindow->emitUpdateProperties( widget );
+ widget->tqgeometry() ) );
+ formWindow->emitUpdateProperties( TQT_TQOBJECT(widget) );
}
void SizeHandle::trySetGeometry( TQWidget *w, int x, int y, int width, int height )
{
- int minw = QMAX( w->minimumSizeHint().width(), w->minimumSize().width() );
- minw = QMAX( minw, 2 * formWindow->grid().x() );
- int minh = QMAX( w->minimumSizeHint().height(), w->minimumSize().height() );
- minh = QMAX( minh, 2 * formWindow->grid().y() );
- if ( QMAX( minw, width ) > w->maximumWidth() ||
- QMAX( minh, height ) > w->maximumHeight() )
+ int minw = TQMAX( w->tqminimumSizeHint().width(), w->tqminimumSize().width() );
+ minw = TQMAX( minw, 2 * formWindow->grid().x() );
+ int minh = TQMAX( w->tqminimumSizeHint().height(), w->tqminimumSize().height() );
+ minh = TQMAX( minh, 2 * formWindow->grid().y() );
+ if ( TQMAX( minw, width ) > w->maximumWidth() ||
+ TQMAX( minh, height ) > w->maximumHeight() )
return;
if ( width < minw && x != w->x() )
x -= minw - width;
if ( height < minh && y != w->y() )
y -= minh - height;
- w->setGeometry( x, y, QMAX( minw, width ), QMAX( minh, height ) );
+ w->setGeometry( x, y, TQMAX( minw, width ), TQMAX( minh, height ) );
}
void SizeHandle::tryResize( TQWidget *w, int width, int height )
{
- int minw = QMAX( w->minimumSizeHint().width(), w->minimumSize().width() );
- minw = QMAX( minw, 16 );
- int minh = QMAX( w->minimumSizeHint().height(), w->minimumSize().height() );
- minh = QMAX( minh, 16 );
- w->resize( QMAX( minw, width ), QMAX( minh, height ) );
+ int minw = TQMAX( w->tqminimumSizeHint().width(), w->tqminimumSize().width() );
+ minw = TQMAX( minw, 16 );
+ int minh = TQMAX( w->tqminimumSizeHint().height(), w->tqminimumSize().height() );
+ minh = TQMAX( minh, 16 );
+ w->resize( TQMAX( minw, width ), TQMAX( minh, height ) );
}
// ------------------------------------------------------------------------
-WidgetSelection::WidgetSelection( FormWindow *parent, TQPtrDict<WidgetSelection> *selDict )
+WidgetSelection::WidgetSelection( FormWindow *tqparent, TQPtrDict<WidgetSelection> *selDict )
: selectionDict( selDict )
{
- formWindow = parent;
+ formWindow = tqparent;
for ( int i = SizeHandle::LeftTop; i <= SizeHandle::Left; ++i ) {
handles.insert( i, new SizeHandle( formWindow, (SizeHandle::Direction)i, this ) );
}
@@ -287,7 +287,7 @@ void WidgetSelection::setWidget( TQWidget *w, bool updateDict )
}
wid = w;
- bool active = !wid->parentWidget() || WidgetFactory::layoutType( wid->parentWidget() ) == WidgetFactory::NoLayout;
+ bool active = !wid->tqparentWidget() || WidgetFactory::tqlayoutType( wid->tqparentWidget() ) == WidgetFactory::NoLayout;
for ( int i = SizeHandle::LeftTop; i <= SizeHandle::Left; ++i ) {
SizeHandle *h = handles[ i ];
if ( h ) {
@@ -308,10 +308,10 @@ bool WidgetSelection::isUsed() const
void WidgetSelection::updateGeometry()
{
- if ( !wid || !wid->parentWidget() )
+ if ( !wid || !wid->tqparentWidget() )
return;
- TQPoint p = wid->parentWidget()->mapToGlobal( wid->pos() );
+ TQPoint p = wid->tqparentWidget()->mapToGlobal( wid->pos() );
p = formWindow->mapFromGlobal( p );
TQRect r( p, wid->size() );
@@ -1,15 +1,15 @@
** Copyright (C) 2000 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the